@@ -41,7 +41,8 @@ from random import randint
 from kamaki.clients.utils.test import Utils
 from kamaki.clients.astakos.test import AstakosClient
 from kamaki.clients.compute.test import ComputeClient, ComputeRestClient
-from kamaki.clients.cyclades.test import CycladesClient
+from kamaki.clients.network.test import (NetworkClient, NetworkRestClient)
+from kamaki.clients.cyclades.test import CycladesClient, CycladesNetworkClient
 from kamaki.clients.cyclades.test import CycladesRestClient
 from kamaki.clients.image.test import ImageClient
 from kamaki.clients.storage.test import StorageClient
@@ -410,7 +411,8 @@ class Client(TestCase):
                 continue
             self.client.request(method, path, **kwargs)
             self.assertEqual(
-                RespInit.mock_calls[-1], call(FR, connection_retry_limit=0))
+                RespInit.mock_calls[-1],
+                call(FR, connection_retry_limit=0, poolsize=None))
 
     @patch('kamaki.clients.Client.request', return_value='lala')
     def _test_foo(self, foo, request):
